"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.init = init;

var _fs = require("fs");

var _promises = require("fs/promises");

var _pathe = require("pathe");

var _types = require("../types");

var _logger = require("@grozav/logger");

var _objectInspect = _interopRequireDefault(require("object-inspect"));

var _config = require("@inkline/config");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const defaultConfigFileContents = `import { defineConfig } from '@inkline/config';

export default defineConfig(${(0, _objectInspect.default)({
  theme: _config.defaultConfig.theme
}, {
  indent: 4,
  depth: Infinity
}).replace(/(\d+[a-zA-Z]+):/g, "'$1':")});
`;

async function init(options) {
  try {
    const cwd = process.cwd();
    const isTypescript = (0, _fs.existsSync)((0, _pathe.resolve)(cwd, "tsconfig.json"));
    const outputFilePath = (0, _pathe.resolve)(cwd, isTypescript ? "inkline.config.ts" : "inkline.config.js");
    await (0, _promises.writeFile)(outputFilePath, defaultConfigFileContents);

    _logger.Logger.default(`Created ${outputFilePath}`);

    _logger.Logger.success(_types.Commands.Init.messages.success);
  } catch (error) {
    _logger.Logger.error(_types.Commands.Init.messages.error);

    _logger.Logger.log(error);
  }
}